@@ -1,4 +1,5 @@
 from .base import AnticaptchaClient
+from pkg_resources import get_distribution, DistributionNotFound
 from .tasks import (
     NoCaptchaTask, NoCaptchaTaskProxylessTask, ImageToTextTask,
     FunCaptchaTask, RecaptchaV3TaskProxyless
@@ -10,4 +11,8 @@ from .fields import (
 )
 AnticatpchaException = AnticaptchaException
 
-__version__ = '0.4.1'
+try:
+    __version__ = get_distribution(__name__).version
+except DistributionNotFound:
+    # package is not installed
+    pass
\ No newline at end of file
